﻿//Copyright (C) 2007-2024 Mariano Ortu <https://www.speedcrypt.info/>

using System;
using System.IO;
using System.Drawing;
using System.Windows.Forms;

using Icons_ListView;
using ListView_Icon.UI;
using ListView_Icon.Nuvola;


namespace ListView_Icon
{
    public partial class FrmMain : Form
    {
        #region Fields
        
        private Icon iconForFile = SystemIcons.WinLogo;

        #endregion Fields

        #region Constructors
        public FrmMain()
        {
            InitializeComponent();
            loadAll();
        }

        #endregion Contructors

        #region Form Routines
        void loadAll()
        {
            //Form Settings

            Text = "ListView Icon Example...";
            StartPosition = FormStartPosition.CenterScreen;
            MaximizeBox = false;
            MinimizeBox = false;
            FormBorderStyle = FormBorderStyle.FixedDialog;
            labOrtu.Text = "Copyright (C) 2007 - " + DateTime.Now.ToString("yyyy") + " Mariano Ortu";

            //Imagelist1
            imageList1.ColorDepth = ColorDepth.Depth32Bit;
            imageList1.Images.Add(Image.FromStream(new MemoryStream(Nuvola_16._16_package)));
            imageList1.Images.Add(Image.FromStream(new MemoryStream(Nuvola_16._16_date)));
            imageList1.Images.Add(Image.FromStream(new MemoryStream(Nuvola_16._16_kthememgr)));

            //File List
            LvFiles.View = View.Details;
            LvFiles.SmallImageList = imageList1;
            LvFiles.ForeColor = Color.DarkBlue;
            LvFiles.BackColor = Color.OldLace;
            LvFiles.BeginUpdate();
            LvFiles.Columns.Add("ID", 28, HorizontalAlignment.Center);
            LvFiles.Columns.Add("PATH", 300, HorizontalAlignment.Left);
            LvFiles.Columns.Add("SIZE", 110, HorizontalAlignment.Left);
            LvFiles.Columns.Add("DATE", 170, HorizontalAlignment.Left);
            LvFiles.Columns.Add("RSIZE", 115, HorizontalAlignment.Left);
            LvFiles.EndUpdate();
            LvFiles.AllowDrop = true;
            LvFiles.Font = new Font("Courier New", 9.25F, FontStyle.Bold);

            //Menu
            infoMenuItem.Click += InfoMenuItem_Click;
            closeMenuItem.Click += CloseMenuItem_Click;

            //Button
            btnIns.Image = Image.FromStream(new MemoryStream(Nuvola_22._22_folder_download));
            btnIns.Cursor = Cursors.Hand;
            btnIns.Click += BtnIns_Click;
            btnClear.Image = Image.FromStream(new MemoryStream(Nuvola_22._22_messagebox_critical));
            btnClear.Cursor = btnIns.Cursor;
            btnClear.Enabled = false;
            btnClear.Click += BtnClear_Click;
        }

        #endregion Form Routines

        #region Menu
        private void CloseMenuItem_Click(object sender, EventArgs e)
        {
            Close();
        }
        private void InfoMenuItem_Click(object sender, EventArgs e)
        {
            FrmInfo frm = new FrmInfo(this)
            {
                StartPosition = FormStartPosition.CenterScreen
            };
            frm.ShowDialog();
        }

        #endregion Menu

        #region Buttons
        private void BtnIns_Click(object sender, EventArgs e)
        {
            try
            {
                OpenFileDialog OpeFilDial = new OpenFileDialog
                {
                    Title = "ListView Icon: Select the Files to add",
                    Multiselect = true,
                    Filter = "All Files | *.*",
                    RestoreDirectory = true
                };

                if (OpeFilDial.ShowDialog() == DialogResult.OK)
                {
                    Application.DoEvents();
                    LvFiles.ShowSubItemIcons(true);
                    LvFiles.SelectedItems.Clear();
                    string[] file = OpeFilDial.FileNames;
                    for (int i = 0; i < OpeFilDial.FileNames.Length; i++)
                    {
                        string fileName = Path.GetFullPath(file[i]);
                        FileInfo oFileInfo = new FileInfo(file[i]);
                        iconForFile = Icon.ExtractAssociatedIcon(file[i]);
                        DateTime dtCreationTime = oFileInfo.CreationTime;
                        ListViewItem item = new ListViewItem(fileName)
                        {
                            Text = ""
                        };
                        if (!imageList1.Images.ContainsKey(fileName))
                        {
                            iconForFile = Icon.ExtractAssociatedIcon(fileName);
                            imageList1.Images.Add(fileName, iconForFile);
                        }
                        item.ImageKey = fileName;
                        item.ImageKey = fileName;
                        item.SubItems.Add(oFileInfo.FullName);
                        item.SubItems.Add(string.Format("{0:#,##0} KB", oFileInfo.Length / 1024).Replace("0 KB", "1 KB"));
                        item.SubItems.Add(dtCreationTime.ToString("dd/MM/yyyy HH:mm"));
                        item.SubItems.Add(oFileInfo.Strbytes());

                        //Prevent duplicate files
                        if (LvFiles.FindItemWithText(oFileInfo.FullName) == null)
                        {
                            LvFiles.Items.Add(item);
                            item.Font = new Font(item.Font, FontStyle.Regular);
                        }
                        //Add icons
                        LvFiles.AddIconToSubitem(LvFiles.Items.Count - 1, 2, 0);
                        LvFiles.AddIconToSubitem(LvFiles.Items.Count - 1, 3, 1);
                        LvFiles.AddIconToSubitem(LvFiles.Items.Count - 1, 4, 2);

                        //Alternate row colors
                        if (item.Index % 2 == 0)
                            item.BackColor = Color.OldLace;
                        else
                            item.BackColor = Color.Lavender;//PeachPuff;
                    }
                }
            }
            finally
            {
                btnClear.Enabled = true;
            }
        }
        private void BtnClear_Click(object sender, EventArgs e)
        {
            DialogResult result = MessageBox.Show("Do you really want to clear the File List?", " ListView Icon Warning Message", MessageBoxButtons.YesNo, MessageBoxIcon.Warning);
            if (result == DialogResult.No)
                return;
            LvFiles.Items.Clear();
            btnClear.Enabled = false;
        }

        #endregion Buttons

    }
}
